@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """Fetch from conda database all available versions of the xarray dependencies and their
-publication date. Compare it against requirements/py37-min-all-deps.yml to verify the
+publication date. Compare it against requirements/min-all-deps.yml to verify the
 policy on obsolete dependencies is being followed. Print a pretty report :)
 """
 import itertools
@@ -29,7 +29,7 @@ IGNORE_DEPS = {
     "pytest-timeout",
 }
 
-POLICY_MONTHS = {"python": 24, "numpy": 18}
+POLICY_MONTHS = {"python": 30, "numpy": 18}
 POLICY_MONTHS_DEFAULT = 12
 POLICY_OVERRIDE: dict[str, tuple[int, int]] = {}
 errors = []
@@ -46,7 +46,7 @@ def warning(msg: str) -> None:
 
 
 def parse_requirements(fname) -> Iterator[tuple[str, int, int, int | None]]:
-    """Load requirements/py37-min-all-deps.yml
+    """Load requirements/min-all-deps.yml
 
     Yield (package name, major version, minor version, [patch version])
     """
@@ -109,6 +109,9 @@ def query_conda(pkg: str) -> dict[tuple[int, int], datetime]:
                 (3, 6): datetime(2016, 12, 23),
                 (3, 7): datetime(2018, 6, 27),
                 (3, 8): datetime(2019, 10, 14),
+                (3, 9): datetime(2020, 10, 5),
+                (3, 10): datetime(2021, 10, 4),
+                (3, 11): datetime(2022, 10, 24),
             }
         )
 
