@@ -1,26 +1,29 @@
+from __future__ import annotations
+
+from collections.abc import Iterable
+from typing import TYPE_CHECKING, Any
+
 import numpy as np
 
-from ..core import indexing
-from ..core.utils import Frozen, FrozenDict, close_on_error
-from ..core.variable import Variable
-from .common import (
+from xarray.backends.common import (
     BACKEND_ENTRYPOINTS,
     AbstractDataStore,
     BackendArray,
     BackendEntrypoint,
     _normalize_path,
 )
-from .file_manager import CachingFileManager
-from .locks import HDF5_LOCK, NETCDFC_LOCK, combine_locks, ensure_lock
-from .store import StoreBackendEntrypoint
+from xarray.backends.file_manager import CachingFileManager
+from xarray.backends.locks import HDF5_LOCK, NETCDFC_LOCK, combine_locks, ensure_lock
+from xarray.backends.store import StoreBackendEntrypoint
+from xarray.core import indexing
+from xarray.core.utils import Frozen, FrozenDict, close_on_error
+from xarray.core.variable import Variable
 
-try:
-    from PseudoNetCDF import pncopen
-
-    has_pseudonetcdf = True
-except ModuleNotFoundError:
-    has_pseudonetcdf = False
+if TYPE_CHECKING:
+    import os
+    from io import BufferedIOBase
 
+    from xarray.core.dataset import Dataset
 
 # psuedonetcdf can invoke netCDF libraries internally
 PNETCDF_LOCK = combine_locks([HDF5_LOCK, NETCDFC_LOCK])
@@ -54,6 +57,7 @@ class PseudoNetCDFDataStore(AbstractDataStore):
 
     @classmethod
     def open(cls, filename, lock=None, mode=None, **format_kwargs):
+        from PseudoNetCDF import pncopen
 
         keywords = {"kwargs": format_kwargs}
         # only include mode if explicitly passed
@@ -102,10 +106,37 @@ class PseudoNetCDFDataStore(AbstractDataStore):
 
 
 class PseudoNetCDFBackendEntrypoint(BackendEntrypoint):
-    available = has_pseudonetcdf
+    """
+    Backend for netCDF-like data formats in the air quality field
+    based on the PseudoNetCDF package.
+
+    It can open:
+    - CAMx
+    - RACM2 box-model outputs
+    - Kinetic Pre-Processor outputs
+    - ICARTT Data files (ffi1001)
+    - CMAQ Files
+    - GEOS-Chem Binary Punch/NetCDF files
+    - and many more
+
+    This backend is not selected by default for any files, so make
+    sure to specify ``engine="pseudonetcdf"`` in ``open_dataset``.
+
+    For more information about the underlying library, visit:
+    https://pseudonetcdf.readthedocs.io
+
+    See Also
+    --------
+    backends.PseudoNetCDFDataStore
+    """
+
+    description = (
+        "Open many atmospheric science data formats using PseudoNetCDF in Xarray"
+    )
+    url = "https://docs.xarray.dev/en/stable/generated/xarray.backends.PseudoNetCDFBackendEntrypoint.html"
 
     # *args and **kwargs are not allowed in open_backend_dataset_ kwargs,
-    # unless the open_dataset_parameters are explicity defined like this:
+    # unless the open_dataset_parameters are explicitly defined like this:
     open_dataset_parameters = (
         "filename_or_obj",
         "mask_and_scale",
@@ -121,19 +152,18 @@ class PseudoNetCDFBackendEntrypoint(BackendEntrypoint):
 
     def open_dataset(
         self,
-        filename_or_obj,
+        filename_or_obj: str | os.PathLike[Any] | BufferedIOBase | AbstractDataStore,
         mask_and_scale=False,
         decode_times=True,
         concat_characters=True,
         decode_coords=True,
-        drop_variables=None,
+        drop_variables: str | Iterable[str] | None = None,
         use_cftime=None,
         decode_timedelta=None,
         mode=None,
         lock=None,
         **format_kwargs,
-    ):
-
+    ) -> Dataset:
         filename_or_obj = _normalize_path(filename_or_obj)
         store = PseudoNetCDFDataStore.open(
             filename_or_obj, lock=lock, mode=mode, **format_kwargs
@@ -154,4 +184,4 @@ class PseudoNetCDFBackendEntrypoint(BackendEntrypoint):
         return ds
 
 
-BACKEND_ENTRYPOINTS["pseudonetcdf"] = PseudoNetCDFBackendEntrypoint
+BACKEND_ENTRYPOINTS["pseudonetcdf"] = ("PseudoNetCDF", PseudoNetCDFBackendEntrypoint)
