@@ -1,20 +1,26 @@
 """Base classes implementing arithmetic for xarray objects."""
+from __future__ import annotations
+
 import numbers
 
 import numpy as np
 
 # _typed_ops.py is a generated file
-from ._typed_ops import (
+from xarray.core._typed_ops import (
     DataArrayGroupByOpsMixin,
     DataArrayOpsMixin,
     DatasetGroupByOpsMixin,
     DatasetOpsMixin,
     VariableOpsMixin,
 )
-from .common import ImplementsArrayReduce, ImplementsDatasetReduce
-from .ops import IncludeCumMethods, IncludeNumpySameMethods, IncludeReduceMethods
-from .options import OPTIONS, _get_keep_attrs
-from .pycompat import dask_array_type
+from xarray.core.common import ImplementsArrayReduce, ImplementsDatasetReduce
+from xarray.core.ops import (
+    IncludeCumMethods,
+    IncludeNumpySameMethods,
+    IncludeReduceMethods,
+)
+from xarray.core.options import OPTIONS, _get_keep_attrs
+from xarray.core.pycompat import is_duck_array
 
 
 class SupportsArithmetic:
@@ -31,20 +37,21 @@ class SupportsArithmetic:
 
     # TODO: allow extending this with some sort of registration system
     _HANDLED_TYPES = (
-        np.ndarray,
         np.generic,
         numbers.Number,
         bytes,
         str,
-    ) + dask_array_type
+    )
 
     def __array_ufunc__(self, ufunc, method, *inputs, **kwargs):
-        from .computation import apply_ufunc
+        from xarray.core.computation import apply_ufunc
 
         # See the docstring example for numpy.lib.mixins.NDArrayOperatorsMixin.
         out = kwargs.get("out", ())
         for x in inputs + out:
-            if not isinstance(x, self._HANDLED_TYPES + (SupportsArithmetic,)):
+            if not is_duck_array(x) and not isinstance(
+                x, self._HANDLED_TYPES + (SupportsArithmetic,)
+            ):
                 return NotImplemented
 
         if ufunc.signature is not None:
@@ -105,8 +112,6 @@ class VariableArithmetic(
 
 class DatasetArithmetic(
     ImplementsDatasetReduce,
-    IncludeReduceMethods,
-    IncludeCumMethods,
     SupportsArithmetic,
     DatasetOpsMixin,
 ):
@@ -116,8 +121,6 @@ class DatasetArithmetic(
 
 class DataArrayArithmetic(
     ImplementsArrayReduce,
-    IncludeReduceMethods,
-    IncludeCumMethods,
     IncludeNumpySameMethods,
     SupportsArithmetic,
     DataArrayOpsMixin,
