@@ -1,11 +1,17 @@
+from __future__ import annotations
+
 import uuid
 from collections import OrderedDict
 from functools import lru_cache, partial
 from html import escape
-from importlib.resources import read_binary
+from importlib.resources import files
 
-from .formatting import inline_variable_array_repr, short_data_repr
-from .options import _get_boolean_with_default
+from xarray.core.formatting import (
+    inline_index_repr,
+    inline_variable_array_repr,
+    short_data_repr,
+)
+from xarray.core.options import _get_boolean_with_default
 
 STATIC_FILES = (
     ("xarray.static.html", "icons-svg-inline.html"),
@@ -17,7 +23,7 @@ STATIC_FILES = (
 def _load_static_files():
     """Lazily load the resource files into memory the first time they are needed"""
     return [
-        read_binary(package, resource).decode("utf-8")
+        files(package).joinpath(resource).read_text(encoding="utf-8")
         for package, resource in STATIC_FILES
     ]
 
@@ -31,12 +37,12 @@ def short_data_repr_html(array):
     return f"<pre>{text}</pre>"
 
 
-def format_dims(dims, coord_names):
+def format_dims(dims, dims_with_index):
     if not dims:
         return ""
 
     dim_css_map = {
-        k: " class='xr-has-index'" if k in coord_names else "" for k, v in dims.items()
+        dim: " class='xr-has-index'" if dim in dims_with_index else "" for dim in dims
     }
 
     dims_li = "".join(
@@ -66,38 +72,7 @@ def _icon(icon_name):
     )
 
 
-def _summarize_coord_multiindex(name, coord):
-    preview = f"({', '.join(escape(l) for l in coord.level_names)})"
-    return summarize_variable(
-        name, coord, is_index=True, dtype="MultiIndex", preview=preview
-    )
-
-
-def summarize_coord(name, var):
-    is_index = name in var.dims
-    if is_index:
-        coord = var.variable.to_index_variable()
-        if coord.level_names is not None:
-            coords = {name: _summarize_coord_multiindex(name, coord)}
-            for lname in coord.level_names:
-                var = coord.get_level_variable(lname)
-                coords[lname] = summarize_variable(lname, var)
-            return coords
-
-    return {name: summarize_variable(name, var, is_index)}
-
-
-def summarize_coords(variables):
-    coords = {}
-    for k, v in variables.items():
-        coords.update(**summarize_coord(k, v))
-
-    vars_li = "".join(f"<li class='xr-var-item'>{v}</li>" for v in coords.values())
-
-    return f"<ul class='xr-var-list'>{vars_li}</ul>"
-
-
-def summarize_variable(name, var, is_index=False, dtype=None, preview=None):
+def summarize_variable(name, var, is_index=False, dtype=None):
     variable = var.variable if hasattr(var, "variable") else var
 
     cssclass_idx = " class='xr-has-index'" if is_index else ""
@@ -110,7 +85,7 @@ def summarize_variable(name, var, is_index=False, dtype=None, preview=None):
     data_id = "data-" + str(uuid.uuid4())
     disabled = "" if len(var.attrs) else "disabled"
 
-    preview = preview or escape(inline_variable_array_repr(variable, 35))
+    preview = escape(inline_variable_array_repr(variable, 35))
     attrs_ul = summarize_attrs(var.attrs)
     data_repr = short_data_repr_html(variable)
 
@@ -134,6 +109,17 @@ def summarize_variable(name, var, is_index=False, dtype=None, preview=None):
     )
 
 
+def summarize_coords(variables):
+    li_items = []
+    for k, v in variables.items():
+        li_content = summarize_variable(k, v, is_index=k in variables.xindexes)
+        li_items.append(f"<li class='xr-var-item'>{li_content}</li>")
+
+    vars_li = "".join(li_items)
+
+    return f"<ul class='xr-var-list'>{vars_li}</ul>"
+
+
 def summarize_vars(variables):
     vars_li = "".join(
         f"<li class='xr-var-item'>{summarize_variable(k, v)}</li>"
@@ -143,6 +129,40 @@ def summarize_vars(variables):
     return f"<ul class='xr-var-list'>{vars_li}</ul>"
 
 
+def short_index_repr_html(index):
+    if hasattr(index, "_repr_html_"):
+        return index._repr_html_()
+
+    return f"<pre>{escape(repr(index))}</pre>"
+
+
+def summarize_index(coord_names, index):
+    name = "<br>".join([escape(str(n)) for n in coord_names])
+
+    index_id = f"index-{uuid.uuid4()}"
+    preview = escape(inline_index_repr(index))
+    details = short_index_repr_html(index)
+
+    data_icon = _icon("icon-database")
+
+    return (
+        f"<div class='xr-index-name'><div>{name}</div></div>"
+        f"<div class='xr-index-preview'>{preview}</div>"
+        f"<div></div>"
+        f"<input id='{index_id}' class='xr-index-data-in' type='checkbox'/>"
+        f"<label for='{index_id}' title='Show/Hide index repr'>{data_icon}</label>"
+        f"<div class='xr-index-data'>{details}</div>"
+    )
+
+
+def summarize_indexes(indexes):
+    indexes_li = "".join(
+        f"<li class='xr-var-item'>{summarize_index(v, i)}</li>"
+        for v, i in indexes.items()
+    )
+    return f"<ul class='xr-var-list'>{indexes_li}</ul>"
+
+
 def collapsible_section(
     name, inline_details="", details="", n_items=None, enabled=True, collapsed=False
 ):
@@ -184,7 +204,7 @@ def _mapping_section(
 
 
 def dim_section(obj):
-    dim_list = format_dims(obj.dims, list(obj.coords))
+    dim_list = format_dims(obj.dims, obj.xindexes.dims)
 
     return collapsible_section(
         "Dimensions", inline_details=dim_list, enabled=False, collapsed=True
@@ -231,6 +251,13 @@ datavar_section = partial(
     expand_option_name="display_expand_data_vars",
 )
 
+index_section = partial(
+    _mapping_section,
+    name="Indexes",
+    details_func=summarize_indexes,
+    max_items_collapse=0,
+    expand_option_name="display_expand_indexes",
+)
 
 attr_section = partial(
     _mapping_section,
@@ -241,6 +268,12 @@ attr_section = partial(
 )
 
 
+def _get_indexes_dict(indexes):
+    return {
+        tuple(index_vars.keys()): idx for idx, index_vars in indexes.group_by_index()
+    }
+
+
 def _obj_repr(obj, header_components, sections):
     """Return HTML repr of an xarray object.
 
@@ -265,15 +298,18 @@ def _obj_repr(obj, header_components, sections):
 
 def array_repr(arr):
     dims = OrderedDict((k, v) for k, v in zip(arr.dims, arr.shape))
+    if hasattr(arr, "xindexes"):
+        indexed_dims = arr.xindexes.dims
+    else:
+        indexed_dims = {}
 
     obj_type = f"xarray.{type(arr).__name__}"
     arr_name = f"'{arr.name}'" if getattr(arr, "name", None) else ""
-    coord_names = list(arr.coords) if hasattr(arr, "coords") else []
 
     header_components = [
         f"<div class='xr-obj-type'>{obj_type}</div>",
         f"<div class='xr-array-name'>{arr_name}</div>",
-        format_dims(dims, coord_names),
+        format_dims(dims, indexed_dims),
     ]
 
     sections = [array_section(arr)]
@@ -281,6 +317,10 @@ def array_repr(arr):
     if hasattr(arr, "coords"):
         sections.append(coord_section(arr.coords))
 
+    if hasattr(arr, "xindexes"):
+        indexes = _get_indexes_dict(arr.xindexes)
+        sections.append(index_section(indexes))
+
     sections.append(attr_section(arr.attrs))
 
     return _obj_repr(arr, header_components, sections)
@@ -295,6 +335,7 @@ def dataset_repr(ds):
         dim_section(ds),
         coord_section(ds.coords),
         datavar_section(ds.data_vars),
+        index_section(_get_indexes_dict(ds.xindexes)),
         attr_section(ds.attrs),
     ]
 
