@@ -59,6 +59,8 @@ class TestDatetimeAccessor:
             "quarter",
             "date",
             "time",
+            "daysinmonth",
+            "days_in_month",
             "is_month_start",
             "is_month_end",
             "is_quarter_start",
@@ -69,13 +71,23 @@ class TestDatetimeAccessor:
         ],
     )
     def test_field_access(self, field) -> None:
-
         if field in ["week", "weekofyear"]:
             data = self.times.isocalendar()["week"]
         else:
             data = getattr(self.times, field)
 
-        expected = xr.DataArray(data, name=field, coords=[self.times], dims=["time"])
+        if data.dtype.kind != "b" and field not in ("date", "time"):
+            # pandas 2.0 returns int32 for integer fields now
+            data = data.astype("int64")
+
+        translations = {
+            "weekday": "dayofweek",
+            "daysinmonth": "days_in_month",
+            "weekofyear": "week",
+        }
+        name = translations.get(field, field)
+
+        expected = xr.DataArray(data, name=name, coords=[self.times], dims=["time"])
 
         if field in ["week", "weekofyear"]:
             with pytest.warns(
@@ -85,7 +97,8 @@ class TestDatetimeAccessor:
         else:
             actual = getattr(self.data.time.dt, field)
 
-        assert_equal(expected, actual)
+        assert expected.dtype == actual.dtype
+        assert_identical(expected, actual)
 
     @pytest.mark.parametrize(
         "field, pandas_field",
@@ -96,7 +109,6 @@ class TestDatetimeAccessor:
         ],
     )
     def test_isocalendar(self, field, pandas_field) -> None:
-
         # pandas isocalendar has dtypy UInt32Dtype, convert to Int64
         expected = pd.Index(getattr(self.times.isocalendar(), pandas_field).astype(int))
         expected = xr.DataArray(
@@ -403,7 +415,6 @@ def times_3d(times):
     "field", ["year", "month", "day", "hour", "dayofyear", "dayofweek"]
 )
 def test_field_access(data, field) -> None:
-
     result = getattr(data.time.dt, field)
     expected = xr.DataArray(
         getattr(xr.coding.cftimeindex.CFTimeIndex(data.time.values), field),
@@ -421,7 +432,6 @@ def test_calendar_cftime(data) -> None:
     assert data.time.dt.calendar == expected
 
 
-@requires_cftime
 def test_calendar_datetime64_2d() -> None:
     data = xr.DataArray(np.zeros((4, 5), dtype="datetime64[ns]"), dims=("x", "y"))
     assert data.dt.calendar == "proleptic_gregorian"
@@ -458,7 +468,6 @@ def test_calendar_dask_cftime() -> None:
 
 @requires_cftime
 def test_isocalendar_cftime(data) -> None:
-
     with pytest.raises(
         AttributeError, match=r"'CFTimeIndex' object has no attribute 'isocalendar'"
     ):
@@ -467,7 +476,6 @@ def test_isocalendar_cftime(data) -> None:
 
 @requires_cftime
 def test_date_cftime(data) -> None:
-
     with pytest.raises(
         AttributeError,
         match=r"'CFTimeIndex' object has no attribute `date`. Consider using the floor method instead, for instance: `.time.dt.floor\('D'\)`.",
