@@ -7,11 +7,10 @@ from textwrap import dedent
 import numpy as np
 import pandas as pd
 import pytest
-from packaging.version import Version
 
 import xarray as xr
 from xarray import DataArray, Variable
-from xarray.core.pycompat import array_type, mod_version
+from xarray.core.pycompat import array_type
 from xarray.tests import assert_equal, assert_identical, requires_dask
 
 filterwarnings = pytest.mark.filterwarnings
@@ -20,7 +19,6 @@ xfail = pytest.mark.xfail
 
 sparse = pytest.importorskip("sparse")
 sparse_array_type = array_type("sparse")
-sparse_version = mod_version("sparse")
 
 
 def assert_sparse_equal(a, b):
@@ -61,7 +59,6 @@ class do:
         self.kwargs = kwargs
 
     def __call__(self, obj):
-
         # cannot pass np.sum when using pytest-xdist
         kwargs = self.kwargs.copy()
         if "func" in self.kwargs:
@@ -856,10 +853,6 @@ class TestSparseCoords:
         )
 
 
-@pytest.mark.xfail(
-    sparse_version < Version("0.13.0"),
-    reason="https://github.com/pydata/xarray/issues/5654",
-)
 @requires_dask
 def test_chunk():
     s = sparse.COO.from_numpy(np.array([0, 0, 1, 2]))
