@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from typing import Any, Iterable
+from collections.abc import Iterable
+from typing import Any
 
 import numpy as np
 import pytest
@@ -18,7 +19,6 @@ from xarray.tests import (
 
 @pytest.mark.parametrize("as_dataset", (True, False))
 def test_weighted_non_DataArray_weights(as_dataset: bool) -> None:
-
     data: DataArray | Dataset = DataArray([1, 2])
     if as_dataset:
         data = data.to_dataset(name="data")
@@ -30,7 +30,6 @@ def test_weighted_non_DataArray_weights(as_dataset: bool) -> None:
 @pytest.mark.parametrize("as_dataset", (True, False))
 @pytest.mark.parametrize("weights", ([np.nan, 2], [np.nan, np.nan]))
 def test_weighted_weights_nan_raises(as_dataset: bool, weights: list[float]) -> None:
-
     data: DataArray | Dataset = DataArray([1, 2])
     if as_dataset:
         data = data.to_dataset(name="data")
@@ -43,7 +42,6 @@ def test_weighted_weights_nan_raises(as_dataset: bool, weights: list[float]) ->
 @pytest.mark.parametrize("as_dataset", (True, False))
 @pytest.mark.parametrize("weights", ([np.nan, 2], [np.nan, np.nan]))
 def test_weighted_weights_nan_raises_dask(as_dataset, weights):
-
     data = DataArray([1, 2]).chunk({"dim_0": -1})
     if as_dataset:
         data = data.to_dataset(name="data")
@@ -85,7 +83,6 @@ def test_weighted_lazy_resample(time_chunks, resample_spec):
     (([1, 2], 3), ([2, 0], 2), ([0, 0], np.nan), ([-1, 1], np.nan)),
 )
 def test_weighted_sum_of_weights_no_nan(weights, expected):
-
     da = DataArray([1, 2])
     weights = DataArray(weights)
     result = da.weighted(weights).sum_of_weights()
@@ -100,7 +97,6 @@ def test_weighted_sum_of_weights_no_nan(weights, expected):
     (([1, 2], 2), ([2, 0], np.nan), ([0, 0], np.nan), ([-1, 1], 1)),
 )
 def test_weighted_sum_of_weights_nan(weights, expected):
-
     da = DataArray([np.nan, 2])
     weights = DataArray(weights)
     result = da.weighted(weights).sum_of_weights()
@@ -141,7 +137,6 @@ def test_weighted_sum_equal_weights(da, factor, skipna):
     ("weights", "expected"), (([1, 2], 5), ([0, 2], 4), ([0, 0], 0))
 )
 def test_weighted_sum_no_nan(weights, expected):
-
     da = DataArray([1, 2])
 
     weights = DataArray(weights)
@@ -156,7 +151,6 @@ def test_weighted_sum_no_nan(weights, expected):
 )
 @pytest.mark.parametrize("skipna", (True, False))
 def test_weighted_sum_nan(weights, expected, skipna):
-
     da = DataArray([np.nan, 2])
 
     weights = DataArray(weights)
@@ -192,7 +186,6 @@ def test_weighted_mean_equal_weights(da, skipna, factor):
     ("weights", "expected"), (([4, 6], 1.6), ([1, 0], 1.0), ([0, 0], np.nan))
 )
 def test_weighted_mean_no_nan(weights, expected):
-
     da = DataArray([1, 2])
     weights = DataArray(weights)
     expected = DataArray(expected)
@@ -230,7 +223,6 @@ def test_weighted_quantile_no_nan(weights, expected):
 
 
 def test_weighted_quantile_zero_weights():
-
     da = DataArray([0, 1, 2, 3])
     weights = DataArray([1, 0, 1, 0])
     q = 0.75
@@ -351,7 +343,6 @@ def test_weighted_quantile_bool():
 
 @pytest.mark.parametrize("q", (-1, 1.1, (0.5, 1.1), ((0.2, 0.4), (0.6, 0.8))))
 def test_weighted_quantile_with_invalid_q(q):
-
     da = DataArray([1, 1.9, 2.2, 3, 3.7, 4.1, 5])
     q = np.asarray(q)
     weights = xr.ones_like(da)
@@ -369,7 +360,6 @@ def test_weighted_quantile_with_invalid_q(q):
 )
 @pytest.mark.parametrize("skipna", (True, False))
 def test_weighted_mean_nan(weights, expected, skipna):
-
     da = DataArray([np.nan, 2])
     weights = DataArray(weights)
 
@@ -399,7 +389,6 @@ def test_weighted_mean_bool():
     (([1, 2], 2 / 3), ([2, 0], 0), ([0, 0], 0), ([-1, 1], 0)),
 )
 def test_weighted_sum_of_squares_no_nan(weights, expected):
-
     da = DataArray([1, 2])
     weights = DataArray(weights)
     result = da.weighted(weights).sum_of_squares()
@@ -414,7 +403,6 @@ def test_weighted_sum_of_squares_no_nan(weights, expected):
     (([1, 2], 0), ([2, 0], 0), ([0, 0], 0), ([-1, 1], 0)),
 )
 def test_weighted_sum_of_squares_nan(weights, expected):
-
     da = DataArray([np.nan, 2])
     weights = DataArray(weights)
     result = da.weighted(weights).sum_of_squares()
@@ -446,7 +434,6 @@ def test_weighted_var_equal_weights(da, skipna, factor):
     ("weights", "expected"), (([4, 6], 0.24), ([1, 0], 0.0), ([0, 0], np.nan))
 )
 def test_weighted_var_no_nan(weights, expected):
-
     da = DataArray([1, 2])
     weights = DataArray(weights)
     expected = DataArray(expected)
@@ -460,7 +447,6 @@ def test_weighted_var_no_nan(weights, expected):
     ("weights", "expected"), (([4, 6], 0), ([1, 0], np.nan), ([0, 0], np.nan))
 )
 def test_weighted_var_nan(weights, expected):
-
     da = DataArray([np.nan, 2])
     weights = DataArray(weights)
     expected = DataArray(expected)
@@ -503,7 +489,6 @@ def test_weighted_std_equal_weights(da, skipna, factor):
     ("weights", "expected"), (([4, 6], np.sqrt(0.24)), ([1, 0], 0.0), ([0, 0], np.nan))
 )
 def test_weighted_std_no_nan(weights, expected):
-
     da = DataArray([1, 2])
     weights = DataArray(weights)
     expected = DataArray(expected)
@@ -517,7 +502,6 @@ def test_weighted_std_no_nan(weights, expected):
     ("weights", "expected"), (([4, 6], 0), ([1, 0], np.nan), ([0, 0], np.nan))
 )
 def test_weighted_std_nan(weights, expected):
-
     da = DataArray([np.nan, 2])
     weights = DataArray(weights)
     expected = DataArray(expected)
@@ -578,7 +562,6 @@ def expected_weighted(da, weights, dim, skipna, operation):
 
 
 def check_weighted_operations(data, weights, dim, skipna):
-
     # check sum of weights
     result = data.weighted(weights).sum_of_weights(dim)
     expected = expected_weighted(data, weights, dim, skipna, "sum_of_weights")
@@ -615,7 +598,6 @@ def check_weighted_operations(data, weights, dim, skipna):
 @pytest.mark.parametrize("skipna", (None, True, False))
 @pytest.mark.filterwarnings("ignore:invalid value encountered in sqrt")
 def test_weighted_operations_3D(dim, add_nans, skipna):
-
     dims = ("a", "b", "c")
     coords = dict(a=[0, 1, 2, 3], b=[0, 1, 2, 3], c=[0, 1, 2, 3])
 
@@ -641,7 +623,6 @@ def test_weighted_operations_3D(dim, add_nans, skipna):
 @pytest.mark.parametrize("add_nans", (True, False))
 @pytest.mark.parametrize("skipna", (None, True, False))
 def test_weighted_quantile_3D(dim, q, add_nans, skipna):
-
     dims = ("a", "b", "c")
     coords = dict(a=[0, 1, 2], b=[0, 1, 2, 3], c=[0, 1, 2, 3, 4])
 
@@ -721,7 +702,6 @@ def test_weighted_operations_nonequal_coords(
 def test_weighted_operations_different_shapes(
     shape_data, shape_weights, add_nans, skipna
 ):
-
     weights = DataArray(np.random.randn(*shape_weights))
 
     data = np.random.randn(*shape_data)
@@ -748,7 +728,6 @@ def test_weighted_operations_different_shapes(
 @pytest.mark.parametrize("as_dataset", (True, False))
 @pytest.mark.parametrize("keep_attrs", (True, False, None))
 def test_weighted_operations_keep_attr(operation, as_dataset, keep_attrs):
-
     weights = DataArray(np.random.randn(2, 2), attrs=dict(attr="weights"))
     data = DataArray(np.random.randn(2, 2))
 
@@ -794,7 +773,6 @@ def test_weighted_operations_keep_attr_da_in_ds(operation):
 @pytest.mark.parametrize("operation", ("sum_of_weights", "sum", "mean", "quantile"))
 @pytest.mark.parametrize("as_dataset", (True, False))
 def test_weighted_bad_dim(operation, as_dataset):
-
     data = DataArray(np.random.randn(2, 2))
     weights = xr.ones_like(data)
     if as_dataset:
